@@ -14,6 +14,7 @@ from io import StringIO
 from contextlib import redirect_stdout
 import threading
 import time
+from nwb_conversion_tools.utils.json_schema import dict_deep_update
 
 
 class ConverterForms(html.Div):
@@ -52,7 +53,7 @@ class ConverterForms(html.Div):
             parent_app=self.parent_app,
             root_path=self.root_path
         )
-        
+
         # Conversion Option Form
         self.conversion_options_forms = SchemaFormContainer(
             id='conversiondata',
@@ -70,10 +71,23 @@ class ConverterForms(html.Div):
         self.style = {'background-color': '#f0f0f0', 'min-height': '100vh'}
 
         self.children = [
+            html.Br(),
             dbc.Container([
                 dbc.Row([
                     html.Br(),
-                    dbc.Col(self.source_forms, width={'size': 12}),
+                    dbc.Col(
+                        dbc.Card([
+                            dbc.Col(
+                                html.H4('Source Data'),
+                                style={'text-align': 'center', 'justify-content': 'center', "margin-top": "15px"},
+                                width={'size': 12}
+                            ),
+                            dbc.CardBody(
+                                self.source_forms
+                            )
+                        ], style={'background-color': '##eceef7', "box-shadow": "2px 2px 2px 2px rgba(0,0,0,0.1)"}),
+                        width={'size': 12}
+                    ),
                     dbc.Col(
                         dbc.Button('Get Metadata Form', id='get_metadata_btn', color='dark'),
                         style={'justify-content': 'left', 'text-align': 'left', 'margin-top': '1%'},
@@ -144,14 +158,27 @@ class ConverterForms(html.Div):
                     style={'margin-top': '1%', 'margin-bottom': '10px'}
                 ),
                 dbc.Row(
-                    dbc.Col(self.conversion_options_forms, id='conversion-col', width={'size': 12}, style={'display': 'none'}),
+                    dbc.Col([
+                        dbc.Card([
+                            dbc.Col(
+                                html.H4('Conversion Options'),
+                                style={'text-align': 'center', 'justify-content': 'center', "margin-top": "15px"},
+                                width={'size': 12}
+                            ),
+                            dbc.CardBody(self.conversion_options_forms)
+                        ], style={'background-color': '##eceef7', "box-shadow": "2px 2px 2px 2px rgba(0,0,0,0.1)"}),
+                    ],
+                        id='conversion-col',
+                        width={'size': 12},
+                        style={'display': 'none'}
+                    )
                 ),
                 dbc.Row(
                     dbc.Col(
                         dbc.InputGroup(
                             [
                                 dbc.InputGroupAddon("Output file: ", addon_type="prepend"),
-                                dbc.Input(id="output-nwbfile-name", placeholder="filename.nwb"),
+                                dbc.Input(id="output-nwbfile-name", value=str(self.root_path)+'/'),
                                 dbc.InputGroupAddon(
                                     dbc.Button('Run Conversion', id='button_run_conversion'),
                                     addon_type="append",
@@ -160,7 +187,7 @@ class ConverterForms(html.Div):
                         ),
                         width={'size': 11}
                     ),
-                    style={'text-align': 'left', 'margin-top': '1%', 'display': 'none'},
+                    style={'text-align': 'left', 'margin-top': '15px', 'display': 'none'},
                     id='row_output_conversion'
                 ),
                 dbc.Row([
@@ -224,16 +251,18 @@ class ConverterForms(html.Div):
             if alerts is not None:
                 return fileoption_is_open, not req_is_open, alerts
 
+            updated_data = dict_deep_update(self.start_metadata_data, output)
+
             # Make temporary files on server side
             # JSON
             exported_file_path = self.downloads_path / 'exported_metadata.json'
             with open(exported_file_path, 'w') as outfile:
-                json.dump(output, outfile, indent=4)
+                json.dump(updated_data, outfile, indent=4)
 
             # YAML
             exported_file_path = self.downloads_path / 'exported_metadata.yaml'
             with open(exported_file_path, 'w') as outfile:
-                yaml.dump(output, outfile, default_flow_style=False)
+                yaml.dump(updated_data, outfile, default_flow_style=False)
 
             return not fileoption_is_open, req_is_open, []
 
@@ -322,6 +351,7 @@ class ConverterForms(html.Div):
 
             # Get metadata data from converter
             self.metadata_json_data = self.converter.get_metadata()
+            self.start_metadata_data = self.metadata_json_data
 
             if self.metadata_forms.children_forms:
                 # Clean form children if exists to render new one
@@ -329,12 +359,40 @@ class ConverterForms(html.Div):
 
             self.metadata_forms.schema = self.metadata_json_schema
             self.metadata_forms.construct_children_forms()
-            self.metadata_forms.update_data(data=self.metadata_json_data)
+
+            output_form = dbc.Card([
+                dbc.Col(
+                    html.H4('Metadata'),
+                    style={'text-align': 'center', 'justify-content': 'center', "margin-top": "15px"},
+                    width={'size': 12}
+                ),
+                dbc.CardBody(self.metadata_forms)
+            ], style={'background-color': '##eceef7', "box-shadow": "2px 2px 2px 2px rgba(0,0,0,0.1)"})
+
+            self.conversion_options_data = self.converter.get_conversion_options()
+
+            try:
+                self.metadata_forms.update_data(data=self.metadata_json_data)
+                self.conversion_options_forms.update_data(data=self.conversion_options_data)
+            except Exception as e:
+                alert_field = ' '.join([w for w in str(e).strip().split('-')[1:] if not w.isdigit()])
+                exception_alert = [
+                    html.H4('Field not found on schema', className='alert-heading'),
+                    html.Hr(),
+                    html.A(
+                        alert_field,
+                        href="#" + f'wrapper-{alert_field}',
+                        className="alert-link"
+                    )
+                ]
+                return [output_form, {'display': 'block'}, {'display': 'block'}, 
+                {'display': 'block'}, {'display': 'block', 'text-align': 'left', 'margin-top': '15px'}, {'font-size': '16px', 'display': 'block', 'height': '100%', "min-height": "200px", "max-height": "600px"},
+                1, True, exception_alert, {'display': 'block', "margin-top": "15px"}]
 
             return [
-                self.metadata_forms, {'display': 'block'}, {'display': 'block'},
-                {'display': 'block'}, {'display': 'block'}, {'font-size': '16px', 'display': 'block', 'height': '100%', "min-height": "200px", "max-height": "600px"},
-                1, alert_is_open, [], {'display': 'block'}
+                output_form, {'display': 'block'}, {'display': 'block'},
+                {'display': 'block'}, {'display': 'block', 'text-align': 'left', 'margin-top': '15px'}, {'font-size': '16px', 'display': 'block', 'height': '100%', "min-height": "200px", "max-height": "600px"},
+                1, alert_is_open, [], {'display': 'block', "margin-top": "15px"}
             ]
 
         @self.parent_app.callback(
@@ -352,9 +410,12 @@ class ConverterForms(html.Div):
             [Input('button_refresh', 'n_clicks')]
         )
         def refresh_forms_links(click):
+
             if click:
                 return str(np.random.rand())
 
+            raise dash.exceptions.PreventUpdate
+
         @self.parent_app.callback(
             Output({'type': 'external-trigger-update-forms-values', 'index': 'metadata-external-trigger-update-forms-values'}, 'children'),
             [
@@ -403,8 +464,8 @@ class ConverterForms(html.Div):
         def download_file(filename):
             return flask.send_from_directory(
                 directory=self.downloads_path,
-                filename=filename,
-                as_attachment=True
+                path=filename,
+                as_attachment=True,
             )
 
         @self.parent_app.callback(
@@ -428,10 +489,12 @@ class ConverterForms(html.Div):
 
             if trigger_source == 'metadata-output-update-finished-verification' and self.convert_controller:
                 # run conversion
-                alerts, metadata = self.metadata_forms.data_to_nested()
+                alerts, metadata_form_data = self.metadata_forms.data_to_nested()
 
                 _, conversion_options_data = self.conversion_options_forms.data_to_nested() # use this metadata to conversion
-                
+
+                metadata = dict_deep_update(self.start_metadata_data, metadata_form_data)
+
                 if alerts is not None:
                     return 0, True, alerts
 
@@ -484,4 +547,3 @@ class ConverterForms(html.Div):
             time.sleep(0.1)
             self.convert_controller = False
             self.conversion_msg_controller = False
-            
