@@ -1,4 +1,4 @@
-from flask import render_template, request
+from flask import render_template, request, redirect
 from flask import current_app as app
 
 
@@ -7,13 +7,16 @@ def home():
     """Landing page."""
     return render_template('home.html')
 
+
 def shutdown_server():
     func = request.environ.get('werkzeug.server.shutdown')
-    if func is None:
-        raise RuntimeError('Not running with the Werkzeug Server')
-    func()
+    if func is not None:
+        #raise RuntimeError('Not running with the Werkzeug Server')
+        func()
+    return
 
-@app.route('/shutdown', methods=['POST', 'GET'])
+
+@app.route('/shutdown/', methods=['POST', 'GET'])
 def shutdown():
     shutdown_server()
     return 'Server down...'
